@@ -501,7 +501,7 @@ class DatasetModel(models.Model):
                 "type": field.db_type(connection),
                 "description": field.help_text,
             }
-            for field in cls._meta.fields if field.name != "id"
+            for field in cls._meta.fields if field.name not in ("id", "object_uuid")
         ]
 
     def serialize(self):
